#!/bin/bash

: "${PORT:=8880}"
: "${CONTROL_PORT:=8881}"

echo "JAVA_OPTS=$JAVA_OPTS"
echo "JAVA_HEAP_MIN=$JAVA_HEAP_MIN"
echo "JAVA_HEAP_MAX=$JAVA_HEAP_MAX"

echo "DEPLOYMENT_PROVIDER=$DEPLOYMENT_PROVIDER"

echo "======================================================================"
echo "Supergen $ROLLBAR_ENV server.sh starting..."

echo "ROLLBAR INFO DIR: $ROLLBARDIR_OVERRIDE"
export ROLLBAR_TOKENS_PATH="$ROLLBARDIR_OVERRIDE/rollbar_team_tokens.json"
export ROLLBAR_MAPPINGS_PATH="$ROLLBARDIR_OVERRIDE/rollbar_mappings.json"
echo "s3 rollbar bucket: $ROLLBAR_BUCKET"

export TZ=UTC
JMX_ARGS="-Dcom.sun.management.jmxremote \
-Dcom.sun.management.jmxremote.authenticate=false \
-Dcom.sun.management.jmxremote.ssl=false \
-Dcom.sun.management.jmxremote.local.only=false \
-Dcom.sun.management.jmxremote.port=1099 \
-Dcom.sun.management.jmxremote.rmi.port=1099 \
-Djava.rmi.server.hostname=127.0.0.1 "

# avoid crazy verbose logging: -XX:+PrintGCDetails -XX:+PrintGCTimeStamps
export JAVA_GC_ARGS="-XX:+UseG1GC -XX:InitiatingHeapOccupancyPercent=35 -Xlog:gc*=warning"
export JAVA_BASE_ARGS="$JAVA_OPTS $JAVA_OOM_OPTS $JAVA_MEMORY_ARGS -Xmx$JAVA_HEAP_MAX -Xms$JAVA_HEAP_MIN $JAVA_GC_ARGS -XshowSettings:vm"
LOG_CONF="config/log4j2.xml"
export SPARK_OPTS="-Dlog4j2.configurationFile=$LOG_CONF -Dspark.executor.memoryOverhead=$SPARK_EXECUTOR_MEM \
-Dspark.driver.memory=$SPARK_DRIVER_MEM -Dspark.driver.memoryOverhead=$SPARK_MEM_OVERHEAD -Dspark.driver.maxResultSize=$SPARK_MAX_RESULT_SIZE \
-Dspark.rdd.compress=true -Dlog4j.debug=true -Dspark.memory.fraction=0.8 -Dspark.memory.storageFraction=0.3 -Dspark.network.timeout=400 \
-Dspark.dynamicAllocation.enabled=false -Dspark.scheduler.barrier.maxConcurrentTasksCheck.maxFailuresMaximum=5"

export SPARK_EVENTLOG_ENABLED=false # can enable to true from the pod if needed
export SPARK_EVENTLOG_DIR=file:/tmp/spark-events
# TODO for the region project, somewhere in helm we'll get a region object so somewhere here we should have
# "AWS_REGION"

echo "printing rabbit host env vars"
# RabbitMQ:
# in production and staging, we would use RABBITMQ_USERNAME/PASSWORD injected by
# the secret from the Jenkinsfile.
# for dev, we use the "local" RabbitMQ broker which is a POD co-deployed in your
# NG k8s dev env. Here, the env vars are $NG_RABBITMQ_USERNAME/PASSWORD (note the
# "NG_" prefix).
env | grep RABBIT | grep HOST
RABBIT_HOST_PARAM="${NG_RABBITMQ_HOST}:${NG_RABBITMQ_SERVICE_PORT}"

echo "printing redis and kafka env vars"
env | grep REDIS
env | grep KAFKA

echo "Using rabbit host=$RABBIT_HOST_PARAM user=$NG_RABBITMQ_USERNAME"

TMP_DIR=/tmp
if [ ! -d /tmp/superscratch ] ; then
    mkdir /tmp/superscratch
fi

echo "STEALTH MODE: $SUPERDRIVER_STEALTH_MODE"
SUPERDRIVER_STEALTH=""
if [[ "${SUPERDRIVER_STEALTH_MODE}" == "true" ]]
then
    SUPERDRIVER_STEALTH="--stealth"
fi

MEXEC_STATEMENT=""
echo "input size based submission mode: ${MEXEC_MODE}"
if [[ "${MEXEC_MODE}" == "true" ]]
then
    MEXEC_STATEMENT="--mexec $MEXEC"
fi

export PREENRICH_ASSET_CUTOFF="$((1024 * 1024 * 100))"
echo "preEnrichAssetCutoff:  ${PREENRICH_ASSET_CUTOFF}"
echo "MEXEC : ${MEXEC}"

# buckets set in yaml files
echo "curbucket: ${CUR_BUCKET}"
echo "superbucket: ${SUPER_BUCKET}"
echo "azureclassicbucket: ${AZURE_CLASSIC_BUCKET}"
echo "assetidbucket: ${ASSETID_BUCKET}"
echo "assetcachebucket: ${ASSET_CACHE_BUCKET}"
echo "regioncachebucket: ${REGION_CACHE_BUCKET}"
echo "alibucket: ${ALI_BUCKET}"
echo "azurebucket: ${AZURE_BUCKET}"
echo "gcpmasterskupath: ${GCP_MASTER_SKU_PATH}"
echo "Using markers location: ${MARKERS_LOCATION}"

# same as "service/server.sh" except "-subsystem supergengcp_ng" for separate queue
java $JAVA_BASE_ARGS $JMX_ARGS $SPARK_OPTS \
  -cp $JAR_FILENAME \
  com.cloudhealthtech.supergen.SuperDriver \
  supergen \
  server \
  --s3creds $SVC_AWS_AUTH_MODE \
  --markers $MARKERS_LOCATION \
  --curbucket $CUR_BUCKET \
  --superbucket $SUPER_BUCKET \
  --azureClassicBucket $AZURE_CLASSIC_BUCKET \
  --assetCacheBucket $ASSET_CACHE_BUCKET \
  --assetidbucket $ASSETID_BUCKET \
  --alibucket $ALI_BUCKET \
  --azurebucket $AZURE_BUCKET \
  --gcpMasterSkuPath $GCP_MASTER_SKU_PATH \
  --redis $REDIS_HOST \
  --kafkahost $KAFKA_HOST \
  --rbenv $RB_ENV \
  --tmpdir $TMP_DIR \
  --dbcreds $DB_CREDS \
  --dbConnPoolProperties \
  "poolType=hikari;minPoolSize=0;maxPoolSize=1;maxConnectionAge=3600;maxIdleTime=600;idleConnectionTestPeriod=60;maxStatements=256" \
  --clusterid $K8S_NS --nonce 42 \
  --rabbiturl    $NG_RABBITMQ_HOST \
  --rabbitpass   $NG_RABBITMQ_PASSWORD \
  --rabbituser   $NG_RABBITMQ_USERNAME \
  --assumeunapportioned --curUpdateRollbar \
  --tagall --addrownum  --assetall \
  --rejectbufsize 32 \
  --dbrscalefactor 400 \
  --parquetScaleFactor $PARQUET_SCALE_FACTOR \
  --ignoreff \
  --biglimit 0 \
  --simpletrans \
  --syntheticIdJoin true \
  --local \
  --writeBeforeEnrichSrcAssetCutoff $PREENRICH_ASSET_CUTOFF \
  --filesPerSlave $FILES_PER_SLAVE --histpriority $HIST_PRIORITY \
  --slavesPerCluster $SLAVES_PER_CLUSTER --threadpool $THREADPOOL \
  --assetscalefactor $ASSET_SCALE_FACTOR \
  --subsystem $SUPERGENGCP_QUEUE_NAME \
  --rolename supergengcp_ng \
  --rollbarTokensPath $ROLLBAR_TOKENS_PATH \
  --rollbarMappingsPath $ROLLBAR_MAPPINGS_PATH \
  --regionCacheBucket  $REGION_CACHE_BUCKET \
  $SUPERGENGCP_VLC_OFFLOAD_CONFIG \
  $SUPERDRIVER_STEALTH \
  $MEXEC_STATEMENT

